(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     58824,       1463]
NotebookOptionsPosition[     54314,       1321]
NotebookOutlinePosition[     55942,       1372]
CellTagsIndexPosition[     55614,       1360]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Black-Scholes Option Model", "DemoTitle",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372877212203125*^9, 3.372877221546875*^9}, {
   3.3728805831875*^9, 3.37288058346875*^9}, {3.372880938125*^9, 
   3.37288093896875*^9}},
 CellID->700863240],

Cell[CellGroupData[{

Cell["", "InitializationSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d1", "[", 
    RowBox[{
    "S_", ",", "k_", ",", "r_", ",", "\[Delta]_", ",", "\[Sigma]_", ",", 
     "T_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"S", "/", "k"}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "-", "\[Delta]", "+", 
         RowBox[{
          SuperscriptBox["\[Sigma]", "2"], "/", "2"}]}], ")"}], " ", "T"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sigma]", " ", 
      SqrtBox["T"]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, 3.372882475734375*^9, {3.372882554265625*^9, 
   3.37288255546875*^9}, {3.3998969495255365`*^9, 3.3998969516817865`*^9}},
 CellID->4075082],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d2", "[", 
    RowBox[{
    "S_", ",", "k_", ",", "r_", ",", "\[Delta]_", ",", "\[Sigma]_", ",", 
     "T_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"S", "/", "k"}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "-", "\[Delta]", "-", 
         RowBox[{
          SuperscriptBox["\[Sigma]", "2"], "/", "2"}]}], ")"}], " ", "T"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sigma]", " ", 
      SqrtBox["T"]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372882475734375*^9, 3.372882477265625*^9}, {
   3.399896957509912*^9, 3.3998969596192865`*^9}},
 CellID->79985652],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[ScriptCapitalN]", "[", "z_", "]"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"Erf", "[", 
        RowBox[{"z", "/", 
         SqrtBox["2"]}], "]"}]}], ")"}], "/", "2"}]}], " ", ";"}], 
  " "}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372882475734375*^9, 3.37288247971875*^9}},
 CellID->412525709],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BSCall", "[", 
    RowBox[{
    "S_", ",", "k_", ",", "r_", ",", "\[Delta]_", ",", "\[Sigma]_", ",", 
     "T_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"S", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[Delta]"}], " ", "T"}]], " ", 
     RowBox[{"\[ScriptCapitalN]", "[", 
      RowBox[{"d1", "[", 
       RowBox[{
       "S", ",", "k", ",", "r", ",", "\[Delta]", ",", "\[Sigma]", ",", "T"}], 
       "]"}], "]"}]}], "-", 
    RowBox[{"k", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "r"}], " ", "T"}]], " ", 
     RowBox[{"\[ScriptCapitalN]", "[", 
      RowBox[{"d2", "[", 
       RowBox[{
       "S", ",", "k", ",", "r", ",", "\[Delta]", ",", "\[Sigma]", ",", "T"}], 
       "]"}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372882475734375*^9, 3.372882482421875*^9}, {
   3.399896965759912*^9, 3.3998969868692865`*^9}},
 CellID->34177612],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BSPut", "[", 
    RowBox[{
    "S_", ",", "k_", ",", "r_", ",", "\[Delta]_", ",", "\[Sigma]_", ",", 
     "T_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"k", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "r"}], " ", "T"}]], " ", 
     RowBox[{"\[ScriptCapitalN]", "[", 
      RowBox[{"-", 
       RowBox[{"d2", "[", 
        RowBox[{
        "S", ",", "k", ",", "r", ",", "\[Delta]", ",", "\[Sigma]", ",", "T"}],
         "]"}]}], "]"}]}], "-", 
    RowBox[{"S", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[Delta]"}], " ", "T"}]], " ", 
     RowBox[{"\[ScriptCapitalN]", "[", 
      RowBox[{"-", 
       RowBox[{"d1", "[", 
        RowBox[{
        "S", ",", "k", ",", "r", ",", "\[Delta]", ",", "\[Sigma]", ",", "T"}],
         "]"}]}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372882475734375*^9, 3.372882481453125*^9}, {
   3.399896975166162*^9, 3.399896983041162*^9}},
 CellID->380955044]
}, Closed]],

Cell[CellGroupData[{

Cell["", "ManipulateSection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
   "d1", ";", "d2", ";", "\[ScriptCapitalN]", ";", "BSCall", ";", "BSPut", 
    ";", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"BSOption", "[", 
       RowBox[{
       "S", ",", " ", "annotation", ",", " ", "r", ",", " ", "\[Delta]", ",", 
        " ", "\[Sigma]", ",", " ", "t"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"S", ",", " ", "70.", ",", " ", "140."}], "}"}], ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<stock price\>\"", ",", " ", "\"\<option price\>\""}], 
        "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
      RowBox[{"ImagePadding", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"25", ",", "55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"25", ",", "25"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "0"}], "}"}]}]}], "]"}]}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"BSOption", ",", "BSCall", ",", "\"\<option\>\""}], "}"}], ",", 
     " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"BSCall", "\[Rule]", "\"\<call\>\""}], ",", " ", 
       RowBox[{"BSPut", "\[Rule]", "\"\<put\>\""}]}], "}"}]}], "}"}], ",", 
   " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"annotation", ",", " ", "100.", ",", "\"\<strike price\>\""}], 
      "}"}], ",", "50.", ",", "150.", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", ".05", ",", "\"\<interest rate\>\""}], "}"}], ",", 
     ".02", ",", ".1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Delta]", ",", ".004", ",", "\"\<dividend yield\>\""}], "}"}],
      ",", " ", ".002", ",", " ", ".05", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]", ",", ".3", ",", " ", "\"\<volatility\>\""}], "}"}], 
     ",", " ", ".2", ",", " ", ".5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", ".1", ",", "\"\<time to maturity\>\""}], "}"}], ",", 
     " ", ".001", ",", "1.", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "5", ",", "6"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372880151390625*^9, 3.372880192140625*^9}, {
   3.372880484375*^9, 3.372880487078125*^9}, {3.372880548578125*^9, 
   3.372880569859375*^9}, {3.3728806570625*^9, 3.372880662640625*^9}, {
   3.37288081*^9, 3.372880820546875*^9}, {3.372882345109375*^9, 
   3.372882397953125*^9}, {3.372882737875*^9, 3.37288274690625*^9}, {
   3.372882818453125*^9, 3.37288282253125*^9}, {3.379881087985731*^9, 
   3.379881218201147*^9}, {3.381364439140625*^9, 3.38136443953125*^9}, {
   3.381364561015625*^9, 3.381364569046875*^9}, {3.399896991853662*^9, 
   3.399896991853662*^9}, {3.399905221072412*^9, 3.399905233197412*^9}, {
   3.399906321103662*^9, 3.399906328384912*^9}},
 CellID->453220963],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`annotation$$ = 
    100., $CellContext`BSOption$$ = $CellContext`BSCall, $CellContext`r$$ = 
    0.05, $CellContext`t$$ = 0.1, $CellContext`\[Delta]$$ = 
    0.004, $CellContext`\[Sigma]$$ = 0.3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`BSOption$$], $CellContext`BSCall, 
       "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
       "put"}}, {{
       Hold[$CellContext`annotation$$], 100., "strike price"}, 50., 150.}, {{
       Hold[$CellContext`r$$], 0.05, "interest rate"}, 0.02, 0.1}, {{
       Hold[$CellContext`\[Delta]$$], 0.004, "dividend yield"}, 0.002, 
      0.05}, {{
       Hold[$CellContext`\[Sigma]$$], 0.3, "volatility"}, 0.2, 0.5}, {{
       Hold[$CellContext`t$$], 0.1, "time to maturity"}, 0.001, 1.}}, 
    Typeset`size$$ = {400., {122., 126.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`BSOption$479021$$ = 
    False, $CellContext`annotation$479022$$ = 0, $CellContext`r$479023$$ = 
    0, $CellContext`\[Delta]$479024$$ = 0, $CellContext`\[Sigma]$479025$$ = 
    0, $CellContext`t$479026$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`annotation$$ = 
        100., $CellContext`BSOption$$ = $CellContext`BSCall, $CellContext`r$$ = 
        0.05, $CellContext`t$$ = 0.1, $CellContext`\[Delta]$$ = 
        0.004, $CellContext`\[Sigma]$$ = 0.3}, "ControllerVariables" :> {
        Hold[$CellContext`BSOption$$, $CellContext`BSOption$479021$$, False], 
        
        Hold[$CellContext`annotation$$, $CellContext`annotation$479022$$, 0], 
        
        Hold[$CellContext`r$$, $CellContext`r$479023$$, 0], 
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$479024$$, 0], 
        Hold[$CellContext`\[Sigma]$$, $CellContext`\[Sigma]$479025$$, 0], 
        Hold[$CellContext`t$$, $CellContext`t$479026$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`d1; $CellContext`d2; $CellContext`\
\[ScriptCapitalN]; $CellContext`BSCall; $CellContext`BSPut; Plot[
         $CellContext`BSOption$$[$CellContext`S, $CellContext`annotation$$, \
$CellContext`r$$, $CellContext`\[Delta]$$, $CellContext`\[Sigma]$$, \
$CellContext`t$$], {$CellContext`S, 70., 140.}, 
         AxesLabel -> {"stock price", "option price"}, ImageSize -> 400, 
         ImagePadding -> {{25, 55}, {25, 25}}, AxesOrigin -> {Automatic, 0}]),
       "Specifications" :> {{{$CellContext`BSOption$$, $CellContext`BSCall, 
          "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
          "put"}}, {{$CellContext`annotation$$, 100., "strike price"}, 50., 
         150., Appearance -> 
         "Labeled"}, {{$CellContext`r$$, 0.05, "interest rate"}, 0.02, 0.1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`\[Delta]$$, 0.004, "dividend yield"}, 
         0.002, 0.05, Appearance -> 
         "Labeled"}, {{$CellContext`\[Sigma]$$, 0.3, "volatility"}, 0.2, 0.5, 
         Appearance -> 
         "Labeled"}, {{$CellContext`t$$, 0.1, "time to maturity"}, 0.001, 1., 
         Appearance -> "Labeled"}}, 
      "Options" :> {AutorunSequencing -> {1, 2, 5, 6}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{446., {231., 236.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`d1[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] + \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`d2[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] - \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`\
\[ScriptCapitalN][
         Pattern[$CellContext`z, 
          Blank[]]] = (1 + Erf[$CellContext`z/Sqrt[2]])/
        2, $CellContext`BSCall[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          Blank[]]] := ($CellContext`S $CellContext`\[ScriptCapitalN][
            $CellContext`d1[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
         E^($CellContext`\[Delta] $CellContext`T) - ($CellContext`k \
$CellContext`\[ScriptCapitalN][
           $CellContext`d2[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
        E^($CellContext`r $CellContext`T), $CellContext`BSPut[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] := ($CellContext`k \
$CellContext`\[ScriptCapitalN][-$CellContext`d2[$CellContext`S, \
$CellContext`k, $CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/
         E^($CellContext`r $CellContext`T) - ($CellContext`S $CellContext`\
\[ScriptCapitalN][-$CellContext`d1[$CellContext`S, $CellContext`k, \
$CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/E^($CellContext`\[Delta] $CellContext`T)}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->67371817]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateCaptionSection"],

Cell["\<\
There are two main types of options that occur in the marketplace: call and \
put options. These give the option buyer the right to buy or to sell the \
security, respectively at a later date, called the maturity date, for a fixed \
price called the strike price. The most popular model for the evaluation of \
these options is called the Black\[Dash]Scholes model after its creators. \
This 2D plot demonstrates how European call and put option prices, determined \
by the Black\[Dash]Scholes model, change for different values of their input \
parameters, which include: current stock price, the strike price, interest \
rate, dividend yield of the stock, volatility or annualized standard \
deviation, and time remaining to maturity.\
\>", "ManipulateCaption",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372873582953125*^9, 3.372873778171875*^9}, {
   3.372873837203125*^9, 3.372874210296875*^9}, {3.372874246359375*^9, 
   3.372874291609375*^9}, {3.37287528090625*^9, 3.372875283140625*^9}, {
   3.372880449515625*^9, 3.372880453375*^9}, 3.37988101420637*^9, {
   3.38136460540625*^9, 3.38136461240625*^9}, {3.382465408894509*^9, 
   3.3824654308321495`*^9}, 3.383071980084405*^9, {3.38307201900628*^9, 
   3.38307201985003*^9}, {3.383072103084405*^9, 3.383072126896905*^9}, 
   3.38307221650628*^9},
 CellID->1044312921]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ThumbnailSection"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`annotation$$ = 
    100., $CellContext`BSOption$$ = $CellContext`BSCall, $CellContext`r$$ = 
    0.05, $CellContext`t$$ = 0.1, $CellContext`\[Delta]$$ = 
    0.004, $CellContext`\[Sigma]$$ = 0.3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`BSOption$$], $CellContext`BSCall, 
       "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
       "put"}}, {{
       Hold[$CellContext`annotation$$], 100., "strike price"}, 50., 150.}, {{
       Hold[$CellContext`r$$], 0.05, "interest rate"}, 0.02, 0.1}, {{
       Hold[$CellContext`\[Delta]$$], 0.004, "dividend yield"}, 0.002, 
      0.05}, {{
       Hold[$CellContext`\[Sigma]$$], 0.3, "volatility"}, 0.2, 0.5}, {{
       Hold[$CellContext`t$$], 0.1, "time to maturity"}, 0.001, 1.}}, 
    Typeset`size$$ = {400., {122., 126.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`BSOption$479105$$ = 
    False, $CellContext`annotation$479106$$ = 0, $CellContext`r$479107$$ = 
    0, $CellContext`\[Delta]$479108$$ = 0, $CellContext`\[Sigma]$479109$$ = 
    0, $CellContext`t$479110$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`annotation$$ = 
        100., $CellContext`BSOption$$ = $CellContext`BSCall, $CellContext`r$$ = 
        0.05, $CellContext`t$$ = 0.1, $CellContext`\[Delta]$$ = 
        0.004, $CellContext`\[Sigma]$$ = 0.3}, "ControllerVariables" :> {
        Hold[$CellContext`BSOption$$, $CellContext`BSOption$479105$$, False], 
        
        Hold[$CellContext`annotation$$, $CellContext`annotation$479106$$, 0], 
        
        Hold[$CellContext`r$$, $CellContext`r$479107$$, 0], 
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$479108$$, 0], 
        Hold[$CellContext`\[Sigma]$$, $CellContext`\[Sigma]$479109$$, 0], 
        Hold[$CellContext`t$$, $CellContext`t$479110$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`d1; $CellContext`d2; $CellContext`\
\[ScriptCapitalN]; $CellContext`BSCall; $CellContext`BSPut; Plot[
         $CellContext`BSOption$$[$CellContext`S, $CellContext`annotation$$, \
$CellContext`r$$, $CellContext`\[Delta]$$, $CellContext`\[Sigma]$$, \
$CellContext`t$$], {$CellContext`S, 70., 140.}, 
         AxesLabel -> {"stock price", "option price"}, ImageSize -> 400, 
         ImagePadding -> {{25, 55}, {25, 25}}, AxesOrigin -> {Automatic, 0}]),
       "Specifications" :> {{{$CellContext`BSOption$$, $CellContext`BSCall, 
          "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
          "put"}}, {{$CellContext`annotation$$, 100., "strike price"}, 50., 
         150., Appearance -> 
         "Labeled"}, {{$CellContext`r$$, 0.05, "interest rate"}, 0.02, 0.1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`\[Delta]$$, 0.004, "dividend yield"}, 
         0.002, 0.05, Appearance -> 
         "Labeled"}, {{$CellContext`\[Sigma]$$, 0.3, "volatility"}, 0.2, 0.5, 
         Appearance -> 
         "Labeled"}, {{$CellContext`t$$, 0.1, "time to maturity"}, 0.001, 1., 
         Appearance -> "Labeled"}}, 
      "Options" :> {AutorunSequencing -> {1, 2, 5, 6}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{446., {231., 236.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`d1[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] + \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`d2[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] - \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`\
\[ScriptCapitalN][
         Pattern[$CellContext`z, 
          Blank[]]] = (1 + Erf[$CellContext`z/Sqrt[2]])/
        2, $CellContext`BSCall[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          Blank[]]] := ($CellContext`S $CellContext`\[ScriptCapitalN][
            $CellContext`d1[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
         E^($CellContext`\[Delta] $CellContext`T) - ($CellContext`k \
$CellContext`\[ScriptCapitalN][
           $CellContext`d2[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
        E^($CellContext`r $CellContext`T), $CellContext`BSPut[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] := ($CellContext`k \
$CellContext`\[ScriptCapitalN][-$CellContext`d2[$CellContext`S, \
$CellContext`k, $CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/
         E^($CellContext`r $CellContext`T) - ($CellContext`S $CellContext`\
\[ScriptCapitalN][-$CellContext`d1[$CellContext`S, $CellContext`k, \
$CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/E^($CellContext`\[Delta] $CellContext`T)}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->94961490]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SnapshotsSection"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`annotation$$ = 
    100., $CellContext`BSOption$$ = $CellContext`BSCall, $CellContext`r$$ = 
    0.057800000000000004`, $CellContext`t$$ = 0.722, $CellContext`\[Delta]$$ =
     0.0138, $CellContext`\[Sigma]$$ = 0.342, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`BSOption$$], $CellContext`BSCall, 
       "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
       "put"}}, {{
       Hold[$CellContext`annotation$$], 100., "strike price"}, 50., 150.}, {{
       Hold[$CellContext`r$$], 0.057800000000000004`, "interest rate"}, 0.02, 
      0.1}, {{
       Hold[$CellContext`\[Delta]$$], 0.0138, "dividend yield"}, 0.002, 
      0.05}, {{
       Hold[$CellContext`\[Sigma]$$], 0.342, "volatility"}, 0.2, 0.5}, {{
       Hold[$CellContext`t$$], 0.722, "time to maturity"}, 0.001, 1.}}, 
    Typeset`size$$ = {400., {122., 126.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`BSOption$479189$$ = 
    False, $CellContext`annotation$479190$$ = 0, $CellContext`r$479191$$ = 
    0, $CellContext`\[Delta]$479192$$ = 0, $CellContext`\[Sigma]$479193$$ = 
    0, $CellContext`t$479194$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`annotation$$ = 
        100., $CellContext`BSOption$$ = $CellContext`BSCall, $CellContext`r$$ = 
        0.057800000000000004`, $CellContext`t$$ = 
        0.722, $CellContext`\[Delta]$$ = 0.0138, $CellContext`\[Sigma]$$ = 
        0.342}, "ControllerVariables" :> {
        Hold[$CellContext`BSOption$$, $CellContext`BSOption$479189$$, False], 
        
        Hold[$CellContext`annotation$$, $CellContext`annotation$479190$$, 0], 
        
        Hold[$CellContext`r$$, $CellContext`r$479191$$, 0], 
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$479192$$, 0], 
        Hold[$CellContext`\[Sigma]$$, $CellContext`\[Sigma]$479193$$, 0], 
        Hold[$CellContext`t$$, $CellContext`t$479194$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`d1; $CellContext`d2; $CellContext`\
\[ScriptCapitalN]; $CellContext`BSCall; $CellContext`BSPut; Plot[
         $CellContext`BSOption$$[$CellContext`S, $CellContext`annotation$$, \
$CellContext`r$$, $CellContext`\[Delta]$$, $CellContext`\[Sigma]$$, \
$CellContext`t$$], {$CellContext`S, 70., 140.}, 
         AxesLabel -> {"stock price", "option price"}, ImageSize -> 400, 
         ImagePadding -> {{25, 55}, {25, 25}}, AxesOrigin -> {Automatic, 0}]),
       "Specifications" :> {{{$CellContext`BSOption$$, $CellContext`BSCall, 
          "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
          "put"}}, {{$CellContext`annotation$$, 100., "strike price"}, 50., 
         150., Appearance -> 
         "Labeled"}, {{$CellContext`r$$, 0.057800000000000004`, 
          "interest rate"}, 0.02, 0.1, Appearance -> 
         "Labeled"}, {{$CellContext`\[Delta]$$, 0.0138, "dividend yield"}, 
         0.002, 0.05, Appearance -> 
         "Labeled"}, {{$CellContext`\[Sigma]$$, 0.342, "volatility"}, 0.2, 
         0.5, Appearance -> 
         "Labeled"}, {{$CellContext`t$$, 0.722, "time to maturity"}, 0.001, 
         1., Appearance -> "Labeled"}}, 
      "Options" :> {AutorunSequencing -> {1, 2, 5, 6}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{446., {231., 236.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`d1[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] + \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`d2[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] - \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`\
\[ScriptCapitalN][
         Pattern[$CellContext`z, 
          Blank[]]] = (1 + Erf[$CellContext`z/Sqrt[2]])/
        2, $CellContext`BSCall[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          Blank[]]] := ($CellContext`S $CellContext`\[ScriptCapitalN][
            $CellContext`d1[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
         E^($CellContext`\[Delta] $CellContext`T) - ($CellContext`k \
$CellContext`\[ScriptCapitalN][
           $CellContext`d2[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
        E^($CellContext`r $CellContext`T), $CellContext`BSPut[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] := ($CellContext`k \
$CellContext`\[ScriptCapitalN][-$CellContext`d2[$CellContext`S, \
$CellContext`k, $CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/
         E^($CellContext`r $CellContext`T) - ($CellContext`S $CellContext`\
\[ScriptCapitalN][-$CellContext`d1[$CellContext`S, $CellContext`k, \
$CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/E^($CellContext`\[Delta] $CellContext`T)}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->570931351],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`annotation$$ = 
    100., $CellContext`BSOption$$ = $CellContext`BSPut, $CellContext`r$$ = 
    0.06, $CellContext`t$$ = 0.791, $CellContext`\[Delta]$$ = 
    0.015550000000000001`, $CellContext`\[Sigma]$$ = 0.4355, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`BSOption$$], $CellContext`BSPut, 
       "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
       "put"}}, {{
       Hold[$CellContext`annotation$$], 100., "strike price"}, 50., 150.}, {{
       Hold[$CellContext`r$$], 0.06, "interest rate"}, 0.02, 0.1}, {{
       Hold[$CellContext`\[Delta]$$], 0.015550000000000001`, 
       "dividend yield"}, 0.002, 0.05}, {{
       Hold[$CellContext`\[Sigma]$$], 0.4355, "volatility"}, 0.2, 0.5}, {{
       Hold[$CellContext`t$$], 0.791, "time to maturity"}, 0.001, 1.}}, 
    Typeset`size$$ = {400., {122., 126.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`BSOption$479273$$ = 
    False, $CellContext`annotation$479274$$ = 0, $CellContext`r$479275$$ = 
    0, $CellContext`\[Delta]$479276$$ = 0, $CellContext`\[Sigma]$479277$$ = 
    0, $CellContext`t$479278$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`annotation$$ = 
        100., $CellContext`BSOption$$ = $CellContext`BSPut, $CellContext`r$$ = 
        0.06, $CellContext`t$$ = 0.791, $CellContext`\[Delta]$$ = 
        0.015550000000000001`, $CellContext`\[Sigma]$$ = 0.4355}, 
      "ControllerVariables" :> {
        Hold[$CellContext`BSOption$$, $CellContext`BSOption$479273$$, False], 
        
        Hold[$CellContext`annotation$$, $CellContext`annotation$479274$$, 0], 
        
        Hold[$CellContext`r$$, $CellContext`r$479275$$, 0], 
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$479276$$, 0], 
        Hold[$CellContext`\[Sigma]$$, $CellContext`\[Sigma]$479277$$, 0], 
        Hold[$CellContext`t$$, $CellContext`t$479278$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`d1; $CellContext`d2; $CellContext`\
\[ScriptCapitalN]; $CellContext`BSCall; $CellContext`BSPut; Plot[
         $CellContext`BSOption$$[$CellContext`S, $CellContext`annotation$$, \
$CellContext`r$$, $CellContext`\[Delta]$$, $CellContext`\[Sigma]$$, \
$CellContext`t$$], {$CellContext`S, 70., 140.}, 
         AxesLabel -> {"stock price", "option price"}, ImageSize -> 400, 
         ImagePadding -> {{25, 55}, {25, 25}}, AxesOrigin -> {Automatic, 0}]),
       "Specifications" :> {{{$CellContext`BSOption$$, $CellContext`BSPut, 
          "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
          "put"}}, {{$CellContext`annotation$$, 100., "strike price"}, 50., 
         150., Appearance -> 
         "Labeled"}, {{$CellContext`r$$, 0.06, "interest rate"}, 0.02, 0.1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`\[Delta]$$, 0.015550000000000001`, 
          "dividend yield"}, 0.002, 0.05, Appearance -> 
         "Labeled"}, {{$CellContext`\[Sigma]$$, 0.4355, "volatility"}, 0.2, 
         0.5, Appearance -> 
         "Labeled"}, {{$CellContext`t$$, 0.791, "time to maturity"}, 0.001, 
         1., Appearance -> "Labeled"}}, 
      "Options" :> {AutorunSequencing -> {1, 2, 5, 6}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{446., {231., 236.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`d1[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] + \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`d2[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] - \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`\
\[ScriptCapitalN][
         Pattern[$CellContext`z, 
          Blank[]]] = (1 + Erf[$CellContext`z/Sqrt[2]])/
        2, $CellContext`BSCall[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          Blank[]]] := ($CellContext`S $CellContext`\[ScriptCapitalN][
            $CellContext`d1[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
         E^($CellContext`\[Delta] $CellContext`T) - ($CellContext`k \
$CellContext`\[ScriptCapitalN][
           $CellContext`d2[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
        E^($CellContext`r $CellContext`T), $CellContext`BSPut[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] := ($CellContext`k \
$CellContext`\[ScriptCapitalN][-$CellContext`d2[$CellContext`S, \
$CellContext`k, $CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/
         E^($CellContext`r $CellContext`T) - ($CellContext`S $CellContext`\
\[ScriptCapitalN][-$CellContext`d1[$CellContext`S, $CellContext`k, \
$CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/E^($CellContext`\[Delta] $CellContext`T)}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->311200935],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`annotation$$ = 
    100., $CellContext`BSOption$$ = $CellContext`BSCall, $CellContext`r$$ = 
    0.09970000000000001, $CellContext`t$$ = 0.001, $CellContext`\[Delta]$$ = 
    0.002, $CellContext`\[Sigma]$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`BSOption$$], $CellContext`BSCall, 
       "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
       "put"}}, {{
       Hold[$CellContext`annotation$$], 100., "strike price"}, 50., 150.}, {{
       Hold[$CellContext`r$$], 0.09970000000000001, "interest rate"}, 0.02, 
      0.1}, {{
       Hold[$CellContext`\[Delta]$$], 0.002, "dividend yield"}, 0.002, 
      0.05}, {{
       Hold[$CellContext`\[Sigma]$$], 0.5, "volatility"}, 0.2, 0.5}, {{
       Hold[$CellContext`t$$], 0.001, "time to maturity"}, 0.001, 1.}}, 
    Typeset`size$$ = {400., {122., 126.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`BSOption$479357$$ = 
    False, $CellContext`annotation$479358$$ = 0, $CellContext`r$479359$$ = 
    0, $CellContext`\[Delta]$479360$$ = 0, $CellContext`\[Sigma]$479361$$ = 
    0, $CellContext`t$479362$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`annotation$$ = 
        100., $CellContext`BSOption$$ = $CellContext`BSCall, $CellContext`r$$ = 
        0.09970000000000001, $CellContext`t$$ = 
        0.001, $CellContext`\[Delta]$$ = 0.002, $CellContext`\[Sigma]$$ = 
        0.5}, "ControllerVariables" :> {
        Hold[$CellContext`BSOption$$, $CellContext`BSOption$479357$$, False], 
        
        Hold[$CellContext`annotation$$, $CellContext`annotation$479358$$, 0], 
        
        Hold[$CellContext`r$$, $CellContext`r$479359$$, 0], 
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$479360$$, 0], 
        Hold[$CellContext`\[Sigma]$$, $CellContext`\[Sigma]$479361$$, 0], 
        Hold[$CellContext`t$$, $CellContext`t$479362$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`d1; $CellContext`d2; $CellContext`\
\[ScriptCapitalN]; $CellContext`BSCall; $CellContext`BSPut; Plot[
         $CellContext`BSOption$$[$CellContext`S, $CellContext`annotation$$, \
$CellContext`r$$, $CellContext`\[Delta]$$, $CellContext`\[Sigma]$$, \
$CellContext`t$$], {$CellContext`S, 70., 140.}, 
         AxesLabel -> {"stock price", "option price"}, ImageSize -> 400, 
         ImagePadding -> {{25, 55}, {25, 25}}, AxesOrigin -> {Automatic, 0}]),
       "Specifications" :> {{{$CellContext`BSOption$$, $CellContext`BSCall, 
          "option"}, {$CellContext`BSCall -> "call", $CellContext`BSPut -> 
          "put"}}, {{$CellContext`annotation$$, 100., "strike price"}, 50., 
         150., Appearance -> 
         "Labeled"}, {{$CellContext`r$$, 0.09970000000000001, 
          "interest rate"}, 0.02, 0.1, Appearance -> 
         "Labeled"}, {{$CellContext`\[Delta]$$, 0.002, "dividend yield"}, 
         0.002, 0.05, Appearance -> 
         "Labeled"}, {{$CellContext`\[Sigma]$$, 0.5, "volatility"}, 0.2, 0.5, 
         Appearance -> 
         "Labeled"}, {{$CellContext`t$$, 0.001, "time to maturity"}, 0.001, 
         1., Appearance -> "Labeled"}}, 
      "Options" :> {AutorunSequencing -> {1, 2, 5, 6}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{446., {231., 236.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`d1[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] + \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`d2[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] = ($CellContext`T ($CellContext`r - $CellContext`\[Delta] - \
$CellContext`\[Sigma]^2/2) + Log[$CellContext`S/$CellContext`k])/(
        Sqrt[$CellContext`T] $CellContext`\[Sigma]), $CellContext`\
\[ScriptCapitalN][
         Pattern[$CellContext`z, 
          Blank[]]] = (1 + Erf[$CellContext`z/Sqrt[2]])/
        2, $CellContext`BSCall[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          Blank[]]] := ($CellContext`S $CellContext`\[ScriptCapitalN][
            $CellContext`d1[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
         E^($CellContext`\[Delta] $CellContext`T) - ($CellContext`k \
$CellContext`\[ScriptCapitalN][
           $CellContext`d2[$CellContext`S, $CellContext`k, $CellContext`r, \
$CellContext`\[Delta], $CellContext`\[Sigma], $CellContext`T]])/
        E^($CellContext`r $CellContext`T), $CellContext`BSPut[
         Pattern[$CellContext`S, 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`\[Delta], 
          Blank[]], 
         Pattern[$CellContext`\[Sigma], 
          Blank[]], 
         Pattern[$CellContext`T, 
          
          Blank[]]] := ($CellContext`k \
$CellContext`\[ScriptCapitalN][-$CellContext`d2[$CellContext`S, \
$CellContext`k, $CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/
         E^($CellContext`r $CellContext`T) - ($CellContext`S $CellContext`\
\[ScriptCapitalN][-$CellContext`d1[$CellContext`S, $CellContext`k, \
$CellContext`r, $CellContext`\[Delta], $CellContext`\[Sigma], \
$CellContext`T]])/E^($CellContext`\[Delta] $CellContext`T)}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->155943479]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "DetailsSection"],

Cell["\<\
Snapshot 1: the positive sloping behavior of the call option which a buyer \
would purchase if he thought that the stock price were going to increase\
\>", "DetailNotes",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372880290921875*^9, 3.372880319953125*^9}, 
   3.38136446228125*^9, {3.381364496015625*^9, 3.38136449678125*^9}},
 CellID->202422114],

Cell["\<\
Snapshot 2: a put option that a buyer would purchase if he thought the stock \
price were going to fall\
\>", "DetailNotes",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372880290921875*^9, 3.372880318125*^9}, {
   3.381364500265625*^9, 3.381364500796875*^9}},
 CellID->172429792],

Cell["\<\
The three most important parameters are the stock price, volatility, and time \
remaining to maturity. Note that for a call, increasing volatility and time \
while decreasing the strike causes an increase in the option price.\
\>", "DetailNotes",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372875974046875*^9, 3.3728760145*^9}, {
   3.37287605684375*^9, 3.372876092890625*^9}, 3.3798810564865375`*^9, 
   3.381364515875*^9},
 CellID->2944906]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ControlSuggestionsSection"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[" Resize Images"]}],
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\"",
  ActionDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"ResizeImages"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Rotate and Zoom in 3D"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" on Mac) and drag up and down to zoom.\""}],
  ActionDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"RotateAndZoomIn3D"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Drag Locators"]}],
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}],
  ActionDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"DragLocators"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Create and Delete Locators"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}],
  ActionDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"CreateAndDeleteLocators"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[" Slider Zoom"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" to make ever finer adjustments.\""}],
  ActionDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"SliderZoom"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Gamepad Controls"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\"",
  ActionDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"GamepadControls"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Automatic Animation"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0], BoxBaselineShift -> 
     0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  ActionDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"AutomaticAnimation"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Bookmark Animation"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0], BoxBaselineShift -> 
     0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  ActionDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"BookmarkAnimation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SearchTermsSection"],

Cell["Black and Scholes", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372875214953125*^9, 3.3728752575*^9}, {
   3.372880394875*^9, 3.372880395359375*^9}},
 CellID->215913997],

Cell["call", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372875214953125*^9, 3.3728752575*^9}, {
   3.372880394875*^9, 3.372880404421875*^9}},
 CellID->53964608],

Cell["derivatives", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372875214953125*^9, 3.3728752575*^9}, {
   3.372880394875*^9, 3.37288041675*^9}},
 CellID->253886195],

Cell["market prices", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372875214953125*^9, 3.3728752575*^9}, {
   3.372880394875*^9, 3.372880402359375*^9}},
 CellID->156076604],

Cell["options", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372875214953125*^9, 3.3728752575*^9}, {
   3.372880394875*^9, 3.372880414890625*^9}},
 CellID->24197797],

Cell["put", "SearchTerms",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372875214953125*^9, 3.3728752575*^9}, {
   3.372880394875*^9, 3.372880404421875*^9}},
 CellID->48592600]
}, Open  ]],

Cell["", "RelatedLinksSection"],

Cell[CellGroupData[{

Cell["", "AuthorSection"],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Michael Kelly",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Michael+Kelly"],
     None}],
 " (Stuart GSB, Illinois Institute of Technology)"
}], "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.37287517796875*^9, 3.37287520784375*^9}, 
   3.37288038696875*^9, {3.38136479028125*^9, 3.3813647943125*^9}, {
   3.399816640231242*^9, 3.399816640231242*^9}, {3.3998969924005365`*^9, 
   3.3998969961817865`*^9}},
 CellID->65550805]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{738, 728},
WindowMargins->{{115, Automatic}, {Automatic, 27}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (July 16, 2007)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "ResizeImages"->{
  Cell[47042, 1108, 310, 8, 22, "ControlSuggestions",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[47355, 1118, 677, 16, 22, "ControlSuggestions",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[48035, 1136, 339, 11, 22, "ControlSuggestions",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[48377, 1149, 636, 15, 22, "ControlSuggestions",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[49016, 1166, 842, 21, 22, "ControlSuggestions",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[49861, 1189, 303, 8, 22, "ControlSuggestions",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[50167, 1199, 1411, 31, 22, "ControlSuggestions",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[51581, 1232, 881, 21, 22, "ControlSuggestions",
   CellTags->"BookmarkAnimation"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"ResizeImages", 54715, 1333},
 {"RotateAndZoomIn3D", 54824, 1336},
 {"DragLocators", 54934, 1339},
 {"CreateAndDeleteLocators", 55050, 1342},
 {"SliderZoom", 55164, 1345},
 {"GamepadControls", 55270, 1348},
 {"AutomaticAnimation", 55383, 1351},
 {"BookmarkAnimation", 55500, 1354}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 250, 5, 74, "DemoTitle",
 CellID->700863240],
Cell[CellGroupData[{
Cell[865, 32, 33, 0, 156, "InitializationSection"],
Cell[901, 34, 763, 24, 35, "Input",
 CellID->4075082],
Cell[1667, 60, 741, 24, 35, "Input",
 CellID->79985652],
Cell[2411, 86, 411, 14, 35, "Input",
 CellID->412525709],
Cell[2825, 102, 998, 29, 27, "Input",
 CellID->34177612],
Cell[3826, 133, 1048, 31, 27, "Input",
 CellID->380955044]
}, Closed]],
Cell[CellGroupData[{
Cell[4911, 169, 29, 0, 188, "ManipulateSection"],
Cell[CellGroupData[{
Cell[4965, 173, 3727, 90, 262, "Input",
 CellID->453220963],
Cell[8695, 265, 7049, 150, 479, "Output",
 CellID->67371817]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15790, 421, 36, 0, 136, "ManipulateCaptionSection"],
Cell[15829, 423, 1338, 21, 127, "ManipulateCaption",
 CellID->1044312921]
}, Open  ]],
Cell[CellGroupData[{
Cell[17204, 449, 28, 0, 168, "ThumbnailSection"],
Cell[17235, 451, 7049, 150, 479, "Output",
 CellID->94961490]
}, Open  ]],
Cell[CellGroupData[{
Cell[24321, 606, 28, 0, 138, "SnapshotsSection"],
Cell[24352, 608, 7155, 152, 479, "Output",
 CellID->570931351],
Cell[31510, 762, 7139, 151, 479, "Output",
 CellID->311200935],
Cell[38652, 915, 7135, 152, 479, "Output",
 CellID->155943479]
}, Open  ]],
Cell[CellGroupData[{
Cell[45824, 1072, 26, 0, 232, "DetailsSection"],
Cell[45853, 1074, 360, 7, 37, "DetailNotes",
 CellID->202422114],
Cell[46216, 1083, 291, 7, 37, "DetailNotes",
 CellID->172429792],
Cell[46510, 1092, 455, 9, 52, "DetailNotes",
 CellID->2944906]
}, Open  ]],
Cell[CellGroupData[{
Cell[47002, 1106, 37, 0, 120, "ControlSuggestionsSection"],
Cell[47042, 1108, 310, 8, 22, "ControlSuggestions",
 CellTags->"ResizeImages"],
Cell[47355, 1118, 677, 16, 22, "ControlSuggestions",
 CellTags->"RotateAndZoomIn3D"],
Cell[48035, 1136, 339, 11, 22, "ControlSuggestions",
 CellTags->"DragLocators"],
Cell[48377, 1149, 636, 15, 22, "ControlSuggestions",
 CellTags->"CreateAndDeleteLocators"],
Cell[49016, 1166, 842, 21, 22, "ControlSuggestions",
 CellTags->"SliderZoom"],
Cell[49861, 1189, 303, 8, 22, "ControlSuggestions",
 CellTags->"GamepadControls"],
Cell[50167, 1199, 1411, 31, 22, "ControlSuggestions",
 CellTags->"AutomaticAnimation"],
Cell[51581, 1232, 881, 21, 22, "ControlSuggestions",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52499, 1258, 30, 0, 152, "SearchTermsSection"],
Cell[52532, 1260, 192, 4, 22, "SearchTerms",
 CellID->215913997],
Cell[52727, 1266, 178, 4, 22, "SearchTerms",
 CellID->53964608],
Cell[52908, 1272, 182, 4, 22, "SearchTerms",
 CellID->253886195],
Cell[53093, 1278, 188, 4, 22, "SearchTerms",
 CellID->156076604],
Cell[53284, 1284, 181, 4, 22, "SearchTerms",
 CellID->24197797],
Cell[53468, 1290, 177, 4, 22, "SearchTerms",
 CellID->48592600]
}, Open  ]],
Cell[53660, 1297, 31, 0, 138, "RelatedLinksSection"],
Cell[CellGroupData[{
Cell[53716, 1301, 25, 0, 124, "AuthorSection"],
Cell[53744, 1303, 542, 14, 22, "Author",
 CellID->65550805]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
